@@ -13,7 +13,7 @@ def build_pdf(
         ...,
         help=(
             "Local folder containing the local LaTeX project."
-            "Must contain an index.tex file."
+            "Must contain main.tex file."
         ),
     ),
 ):
@@ -30,7 +30,7 @@ def build_pdf(
     typer.echo(f"Target folder: {target}")
     typer.echo("Invoking xelatex...")
     try:
-        XELATEX_CMD = f'cd {target}; latexmk -f -xelatex -synctex=1 -interaction=nonstopmode -file-line-error -latexoption="-shell-escape" index.tex'
+        XELATEX_CMD = f'cd {target}; latexmk -f -xelatex -synctex=1 -interaction=nonstopmode -file-line-error -latexoption="-shell-escape" main.tex'
         ret_val = subprocess.run(XELATEX_CMD, shell=True)
         if ret_val.returncode != 0:
             typer.echo(
