@@ -1,6 +1,6 @@
 from .LatexArticle import LatexArticle
-from .LatexProjectBuilder import LatexProjectBuilder
+from .LatexProject import LatexProject
 from .LatexBlockVersion import LatexBlockVersion
-from .TemplateLoader import TemplateLoader
+from .OnlineTemplateLoader import OnlineTemplateLoader
 from .templating.TemplateOptions import TemplateOptions
 from .templating.TemplateRenderer import TemplateRenderer
