@@ -3,7 +3,7 @@ import os
 import pkg_resources
 import logging
 import yaml
-from typing import Dict, Any, Optional, Union
+from typing import Dict, Any, Optional, Set, Union, cast
 from pykwalify.core import Core
 
 
@@ -48,6 +48,10 @@ class TemplateOptions:
     def tex_format(self):
         return self._tex_format
 
+    def get_allowed_tags(self) -> Set[str]:
+        return set(self.tagged.keys())
+
+
     def get(self, path: str, default: Any = None):
         """
         Get a value from the template options on the specified path
@@ -99,13 +103,11 @@ class TemplateOptions:
         return self._parser.source["config"]["schema"]
 
     @property
-    def tagged(self):
+    def tagged(self) -> Dict:
         """
         Return the tagged section
         """
-        if self._parser is None or self._parser.source is None:
-            return {}
-        return self._parser.source["config"]["tagged"]
+        return cast(Dict, self.get("config.tagged", {}))
 
     @property
     def user_options(self):
