@@ -12,4 +12,8 @@ def run_regex_matchers(regex_matchers: List[str], content: str):
     for matcher in regex_matchers:
         match = re.finditer(matcher, content)
         list_of_matches.append(match)
-    return list(chain(*list_of_matches)) if len(list_of_matches) > 1 else list_of_matches[0]
+    return (
+        list(chain(*list_of_matches))
+        if len(list_of_matches) > 1
+        else list_of_matches[0]
+    )
